@@ -1,4 +1,4 @@
-/* $Id: scat.c,v 1.4 2006/02/19 23:59:12 hvengel Exp $ */
+/* $Id: scat.c,v 1.6 2006/04/05 02:11:59 jpizzi Exp $ */
 /* 
  * Argyll Color Correction System
  * Multi-dimensional regularized splines data fitter
@@ -1116,7 +1116,7 @@ static double opt_smooth(
 
 	/* Real world correction factors - */
 	/* correct for real world device smoothnesses. */
-	double rwf[4] = { 0.1, 0.1, 0.1, 0.1 };
+	double rwf[4] = { 1.0, 1.0, 1.0, 1.0 };
 
 /* printf("~1 opt_smooth called with di = %d, ndp = %d, ad = %f\n",di,ndp,ad); */
 	if (di < 1)
@@ -1866,6 +1866,7 @@ solve_gres(mgtmp *m, double tol, int final)
 	/* int *ixcol = m->q.ixcol; */	/* A array column translation from sparse to packed index */ 
 	double *b  = m->q.b;		/* b vector for RHS of simultabeous equation */
 	double *x  = m->q.x;		/* x vector for result */
+    int ni;                     /* number of iterations */
 
 	/*
 	 * The regular spline fitting problem to be solved here strongly
@@ -1961,7 +1962,7 @@ solve_gres(mgtmp *m, double tol, int final)
 				printf("one_itter1 at res %d has err %f, derr %f\n",gres[0],err,derr);
 #endif
 			} else {	/* Use just relaxation */
-				int j, ni;		/* Number of itters */
+				int j;
 				if (i == jitters) {	/* Never done a relaxation itter before */
 					ni = 1;		/* Just do one, to get estimate */
 				} else {
@@ -1979,9 +1980,9 @@ solve_gres(mgtmp *m, double tol, int final)
 #ifdef DEBUG_PROGRESS
 				printf("%d * one_itter2 at res %d has err %f, derr %f\n",ni,gres[0],err,derr);
 #endif
-				if (s->verbose) {
-					printf("*"); fflush(stdout);
-				}
+	/* 			if (s->verbose) {
+    printf("*"); fflush(stdout);  
+   }*/
 			}
 #ifdef OVERRLX
 			if (derr > 0.7 && derr < 1.0) {
